<?php
/**
 * @file
 * Commerce Registry rules integration.
 */

/**
 * Implements hook_rules_event_info().
 */
function commerce_registry_rules_event_info() {
  $events['commerce_registry_new'] = array(
    'label' => t('A registry is created'),
    'group' => t('Commerce Registry'),
    'variables' => array(
      'commerce_registry' => array(
        'label' => t('Commerce Registry'),
        'type' => 'commerce_registry',
      ),
      'owner' => array(
        'label' => t('The new registry owner'),
        'type' => 'user',
      ),
    ),
  );
  $events['commerce_registry_update'] = array(
    'label' => t('A registry is updated'),
    'group' => t('Commerce Registry'),
    'variables' => array(
      'commerce_registry' => array(
        'label' => t('Commerce Registry'),
        'type' => 'commerce_registry',
      ),
    ),
  );
  $events['commerce_registry_product_add'] = array(
    'label' => t('Product is added to a registry'),
    'group' => t('Commerce Registry'),
    'variables' => array(
      'commerce_registry' => array(
        'label' => t('Commerce Registry'),
        'type' => 'commerce_registry',
      ),
      'commerce_product' => array(
        'label' => t('Commerce Product'),
        'type' => 'commerce_product',
      ),
      'added_by_user' => array(
        'label' => t('User that added this product'),
        'type' => 'user',
      ),
    ),
  );
  $events['commerce_registry_product_remove'] = array(
    'label' => t('Product is removed from a registry'),
    'group' => t('Commerce Registry'),
    'variables' => array(
      'commerce_registry' => array(
        'label' => t('Commerce Registry'),
        'type' => 'commerce_registry',
      ),
      'commerce_product' => array(
        'label' => t('Commerce Product'),
        'type' => 'commerce_product',
      ),
    ),
  );
  $events['commerce_registry_product_purchased'] = array(
    'label' => t('A registry product is purchased'),
    'group' => t('Commerce Registry'),
    'variables' => array(
      'commerce_registry' => array(
        'label' => t('The Commerce Registry for the purchase'),
        'type' => 'commerce_registry',
      ),
      'commerce_product' => array(
        'label' => t('Commerce Product that was purchased'),
        'type' => 'commerce_product',
      ),
      'quantity' => array(
        'label' => t('Quantity of product purchased'),
        'type' => 'integer',
      ),
      'purchaser' => array(
        'label' => t('User that purchased this product'),
        'type' => 'user',
      ),
      'commerce_order' => array(
        'label' => t('Commerce Order of the purchase'),
        'type' => 'commerce_order',
      ),
    ),
  );

  return $events;
}

/**
 * Implements hook_rules_condition_info().
 */
function commerce_registry_rules_condition_info() {
}

/**
 * Implements hook_rules_action_info().
 */
function commerce_registry_rules_action_info() {
  $actions['commerce_registry_mark_product_purchased'] = array(
    'label' => t('Mark a registry product as purchased'),
    'group' => t('Commerce Registry'),
    'parameter' => array(
      'commerce_registry' => array(
        'label' => t('Commerce Registry that the product was purchased for'),
        'type' => 'commerce_registry',
      ),
      'commerce_line_item' => array(
        'label' => t('Commerce Line Item containing the product that was purchased'),
        'type' => 'commerce_line_item',
      ),
    ),
  );

  return $actions;
}

/**
 * Action callback: Adds a purchased product to the registry.
 */
function commerce_registry_mark_product_purchased($registry, $lineitem) {
  global $user;
  $line_item_wrapper = entity_metadata_wrapper('commerce_line_item', $lineitem);
  $product = $line_item_wrapper->commerce_product->value();
  $order = $line_item_wrapper->commerce_order->value();
  $quantity = $line_item_wrapper->quantity->value();
  $record = (object) array(
    'registry_id' => $registry->registry_id,
    'product_id' => $product->product_id,
    'order_id' => $order->order_id,
    'quantity' => $quantity,
    'purchaser_uid' => $user->uid,
  );
  drupal_write_record('commerce_registry_purchased', $record);
  // Trigger all rules and hooks.
  rules_invoke_all('commerce_registry_product_purchased', $registry, $product, $quantity, $user, $order);
}
