<?php
/**
 * @file
 * Commerce Registry forms.
 */

/**
 * Show a login form to view a registry.
 */
function commerce_registry_registry_login_form($form, &$form_state, $registry) {
  $form_state['commerce_registry'] = $registry;
  $form = array();
  $form['registry'] = array(
    '#type' => 'markup',
    '#markup' => 'Log in to view the <em>' . $registry->name . '</em> registry',
  );
  $form['password'] = array(
    '#type' => 'password',
    '#title' => 'Registry Password',
  );
  $form['login'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
  );

  return $form;
}

/**
 * Login form validate handler.
 */
function commerce_registry_registry_login_form_validate($form, &$form_state) {
  global $user;
  $registry = $form_state['commerce_registry'];
  if ($registry->loginLimit($user)) {
    form_set_error('password', t('You have reached the login limit for this registry. Try again in 15 minutes. All further login attempts will be logged.'));
    return FALSE;
  }
  elseif (!$registry->login($user, $password)) {
    form_set_error('password', t('You either have no permission to view this registry, or entered an invalid password.'));
    return FALSE;
  }
  return TRUE;
}

/**
 * Login form submit handler: Redirect to the registry.
 */
function commerce_registry_registry_login_form_submit($form, &$form_state) {
  $registry = $form_state['commerce_registry'];
  drupal_set_message(t('Successfully logged in to view the registry !name.', array('!name' => $registry->name)));
  $uri = $registry->defaultUri();
  drupal_goto($uri['path']);
}

/**
 * Form to create a new registry.
 */
function commerce_registry_registry_new_form($form, &$form_state, $type = 'registry') {
  $form_state['registry_bundle'] = $type;
  $form = array();
  $form['registry'] = array(
    '#type' => 'fieldset',
    '#title' => t('Create a Registry'),
    '#tree' => TRUE,
  );
  $type_object = commerce_registry_type_load($type);
  $form['registry']['type'] = array(
    '#type' => 'item',
    '#markup' => $type_object->label,
    '#title' => t('Registry Type'),
  );
  $form['registry']['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Registry Name'),
    '#required' => TRUE,
    '#weight' => 0,
  );
  $form['registry']['public'] = array(
    '#type' => 'radios',
    '#title' => t('Type'),
    '#options' => array(
      1 => t('Public'),
      0 => t('Private'),
    ),
    '#default_value' => 1,
    '#required' => TRUE,
    '#weight' => 1,
  );
  $form['registry']['password'] = array(
    '#type' => 'password',
    '#title' => t('Password'),
    '#states' => array(
      'visible' => array(
        ':input[name="registry[public]"]' => array('value' => 0),
      ),
    ),
    '#weight' => 2,
  );
  $form['registry']['description'] = array(
    '#type' => 'textarea',
    '#title' => t('Description'),
    '#weight' => 3,
  );
  $form['registry']['status'] = array(
    '#type' => 'radios',
    '#title' => t('Status'),
    '#options' => array(
      0 => t('Disabled'),
      1 => t('Enabled'),
    ),
    '#required' => TRUE,
    '#default_value' => 1,
    '#weight' => 4,
  );
  global $user;
  $path = 'user/' . $user->uid . '/registry/new';
  $form['registry']['actions'] = array(
    '#type' => 'actions',
    'submit' => array(
      '#type' => 'submit',
      '#value' => t('Create Registry'),
    ),
    'cancel' => array(
      '#type' => 'markup',
      '#markup' => l(t('Cancel'), $path),
    ),
  );
  return $form;
}

/**
 * New registry form validate handler.
 */
function commerce_registry_registry_new_form_validate($form, &$form_state) {
  if ($form_state['values']['registry']['public'] == 0) {
    $pass = $form_state['values']['registry']['password'];
    if (strlen($pass) == 0) {
      form_set_error('registry][password', t('You must enter a password for a private registry.'));
      return FALSE;
    }
    elseif (strlen($pass) < 6) {
      form_set_error('registry][password', t('The password must be at least 6 characters long.'));
      return FALSE;
    }
  }
  return TRUE;
}

/**
 * New registry form submit handler.
 */
function commerce_registry_registry_new_form_submit($form, $form_state) {
  global $user;
  $values = $form_state['values']['registry'];
  $values['type'] = $form_state['registry_bundle'];
  $values['owner_uid'] = $user->uid;
  $registry = entity_create('commerce_registry', $values);
  entity_save('commerce_registry', $registry);
  drupal_set_message(t('Registry !registry created successfully.', array('!registry' => '<em>' . $registry->name . '</em>')));
  drupal_goto('registry/' . $registry->url);
}
